@@ -24,7 +24,7 @@ import re
 
 from debian.deb822 import Changes
 from devscripts.logger import Logger
-from distro_info import DebianDistroInfo
+from distro_info import DebianDistroInfo, DistroDataOutdated
 from httplib2 import Http, HttpLib2Error
 
 from ubuntutools.lp import udtexceptions
@@ -37,7 +37,10 @@ def get_debian_srcpkg(name, release):
     debian = Distribution('debian')
     debian_archive = debian.getArchive()
 
-    release = DebianDistroInfo().codename(release, None, release)
+    try:
+        release = DebianDistroInfo().codename(release, None, release)
+    except DistroDataOutdated, e:
+        Logger.warn(e)
 
     return debian_archive.getSourcePackage(name, release)
 
